pub struct Checkpoint(pub u64);Expand description
Monotonic sequence number. “I’ve seen everything up to this ID.”
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for Checkpoint
impl Clone for Checkpoint
Sourcefn clone(&self) -> Checkpoint
fn clone(&self) -> Checkpoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Checkpoint
impl Debug for Checkpoint
Sourceimpl<'de> Deserialize<'de> for Checkpoint
impl<'de> Deserialize<'de> for Checkpoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Checkpoint
impl JsonSchema for Checkpoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for Checkpoint
impl Ord for Checkpoint
Sourcefn cmp(&self, other: &Checkpoint) -> Ordering
fn cmp(&self, other: &Checkpoint) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Checkpoint
impl PartialEq for Checkpoint
Sourceimpl PartialOrd for Checkpoint
impl PartialOrd for Checkpoint
Sourceimpl Serialize for Checkpoint
impl Serialize for Checkpoint
impl Copy for Checkpoint
impl Eq for Checkpoint
impl StructuralPartialEq for Checkpoint